( cd usr/bin ; rm -rf emacs )
( cd usr/bin ; ln -sf emacs-20.7-with-x11 emacs )
( cd usr/doc/emacs-20.7 ; rm -rf etc )
( cd usr/doc/emacs-20.7 ; ln -sf /usr/share/emacs/20.7/etc etc )
( cd usr/share/emacs/20.7 ; rm -rf site-lisp )
( cd usr/share/emacs/20.7 ; ln -sf ../site-lisp site-lisp )
