;;; cus-load.el --- automatically extracted custom dependencies
;;
;;; Code:

(put 'holidays 'custom-loads '("calendar"))
(put 'SQL 'custom-loads '("sql"))
(put 'refbib 'custom-loads '("refbib"))
(put 'elp 'custom-loads '("elp"))
(put 'ffap 'custom-loads '("ffap"))
(put 'shell 'custom-loads '("dirtrack" "shell" "terminal"))
(put 'locate 'custom-loads '("locate"))
(put 'highlight-changes 'custom-loads '("hilit-chg"))
(put 'nnmail 'custom-loads '("nnmail"))
(put 'chistory 'custom-loads '("chistory"))
(put 'shell-directories 'custom-loads '("shell"))
(put 'calendar-tex 'custom-loads '("cal-tex"))
(put 'mail-hist 'custom-loads '("mail-hist"))
(put 'gnus-article-emphasis 'custom-loads '("gnus-art"))
(put 'dunnet 'custom-loads '("dunnet"))
(put 'fortran 'custom-loads '("f90" "fortran"))
(put 'feedmail-header 'custom-loads '("feedmail"))
(put 'reftex-table-of-contents-browser 'custom-loads '("reftex"))
(put 'mspools 'custom-loads '("mspools"))
(put 'gnus-article-headers 'custom-loads '("gnus-art" "gnus-sum"))
(put 'f90 'custom-loads '("f90"))
(put 'allout 'custom-loads '("allout"))
(put 'ediff-hook 'custom-loads '("ediff-init"))
(put 'ps-print-vertical 'custom-loads '("ps-print"))
(put 'supercite-hooks 'custom-loads '("supercite"))
(put 'chinese-calendar 'custom-loads '("cal-china"))
(put 'vhdl-menu 'custom-loads '("vhdl-mode"))
(put 'gnus-newsrc 'custom-loads '("gnus-start"))
(put 'expand 'custom-loads '("expand"))
(put 'texmathp 'custom-loads '("reftex"))
(put 'bookmark 'custom-loads '("bookmark"))
(put 'icon 'custom-loads '("icon"))
(put 'nnmail-procmail 'custom-loads '("nnmail"))
(put 'desktop 'custom-loads '("desktop"))
(put 'cperl-help-system 'custom-loads '("cperl-mode"))
(put 'comint-completion 'custom-loads '("comint"))
(put 'gnus-score-kill 'custom-loads '("gnus-kill" "gnus"))
(put 'remote-compile 'custom-loads '("rcompile"))
(put 'gnus-visual 'custom-loads '("earcon" "gnus-art" "gnus"))
(put 'dabbrev 'custom-loads '("dabbrev"))
(put 'completion 'custom-loads '("completion"))
(put 'cpp 'custom-loads '("cpp"))
(put 'auto-show 'custom-loads '("auto-show"))
(put 'gnus-score-expire 'custom-loads '("gnus-kill" "gnus-score"))
(put 'supercite-frames 'custom-loads '("supercite"))
(put 'dirtrack 'custom-loads '("dirtrack"))
(put 'ediff-window 'custom-loads '("ediff-wind"))
(put 'bruce 'custom-loads '("bruce"))
(put 'windows 'custom-loads '("window" "follow"))
(put 'gnus-exit 'custom-loads '("gnus-group" "gnus"))
(put 'speedbar 'custom-loads '("speedbar"))
(put 'etags 'custom-loads '("etags"))
(put 'f90-indent 'custom-loads '("f90"))
(put 'octave-inferior 'custom-loads '("octave-inf" "octave-mod"))
(put 'gnus-summary-maneuvering 'custom-loads '("gnus-sum"))
(put 'gnus-start 'custom-loads '("gnus-group" "gnus-int" "gnus-start" "gnus-util" "gnus"))
(put 'dcl 'custom-loads '("dcl-mode"))
(put 'ogonek 'custom-loads '("ogonek"))
(put 'gnus-extract-view 'custom-loads '("gnus-sum" "gnus-uu"))
(put 'dired-keys 'custom-loads '("dired-x"))
(put 'lisp-mnt 'custom-loads '("lisp-mnt"))
(put 'ediff-mult 'custom-loads '("ediff-mult"))
(put 'mpuz 'custom-loads '("mpuz"))
(put 'find-file 'custom-loads '("files" "find-file"))
(put 'fortran-comment 'custom-loads '("fortran"))
(put 'viper 'custom-loads '("viper-ex" "viper-init" "viper-keym" "viper-macs" "viper-mous" "viper"))
(put 'gnus-undo 'custom-loads '("gnus-undo"))
(put 'widget-faces 'custom-loads '("wid-edit"))
(put 'resize-minibuffer 'custom-loads '("rsz-mini"))
(put 'info-lookup 'custom-loads '("info-look"))
(put 'gnus-various 'custom-loads '("gnus-sum" "gnus"))
(put 'vhdl-compile 'custom-loads '("vhdl-mode"))
(put 'font-lock-highlighting-faces 'custom-loads '("font-lock" "vhdl-mode"))
(put 'flyspell 'custom-loads '("flyspell"))
(put 'ange-ftp 'custom-loads '("ange-ftp"))
(put 'font-lock-extra-types 'custom-loads '("font-lock"))
(put 'minibuffer 'custom-loads '("simple" "complete" "icomplete"))
(put 'gnus-meta 'custom-loads '("gnus"))
(put 'mouse-sel 'custom-loads '("mouse-sel"))
(put 'sort 'custom-loads '("sort"))
(put 'trace 'custom-loads '("trace"))
(put 'gnus-article-washing 'custom-loads '("gnus-art"))
(put 'mh-hook 'custom-loads '("mh-e"))
(put 'yow 'custom-loads '("yow"))
(put 'reftex-defining-label-environments 'custom-loads '("reftex"))
(put 'asm 'custom-loads '("asm-mode"))
(put 'gnus-score-files 'custom-loads '("gnus-score" "gnus"))
(put 'mail-abbrev 'custom-loads '("mailabbrev"))
(put 'feedmail 'custom-loads '("feedmail"))
(put 'gnus-agent 'custom-loads '("gnus-agent"))
(put 'message-news 'custom-loads '("message"))
(put 'bib 'custom-loads '("bib-mode"))
(put 'vhdl-align 'custom-loads '("vhdl-mode"))
(put 'iswitchb 'custom-loads '("iswitchb"))
(put 'custom-buffer 'custom-loads '("cus-edit"))
(put 'vhdl-header 'custom-loads '("vhdl-mode"))
(put 'tex-run 'custom-loads '("tex-mode"))
(put 'reftex-finding-files 'custom-loads '("reftex"))
(put 'iso-acc 'custom-loads '("iso-acc"))
(put 'gnus-summary-pick 'custom-loads '("gnus-salt"))
(put 'gnus-thread 'custom-loads '("gnus-sum"))
(put 'languages 'custom-loads '("cus-edit" "info-look" "ada-mode" "asm-mode" "cperl-mode" "dcl-mode" "fortran" "hideshow" "icon" "m4-mode" "meta-mode" "modula2" "octave-mod" "pascal" "perl-mode" "prolog" "sh-script" "simula" "tcl-mode" "vhdl-mode" "sgml-mode"))
(put 'reftex-miscellaneous-configurations 'custom-loads '("reftex"))
(put 'ediff-ptch 'custom-loads '("ediff-ptch"))
(put 'jka-compr 'custom-loads '("jka-compr"))
(put 'development 'custom-loads '("cus-edit"))
(put 'ediff 'custom-loads '("ediff-diff" "ediff-init" "ediff-mult" "ediff-ptch" "ediff-wind" "ediff"))
(put 'feedmail-spray 'custom-loads '("feedmail"))
(put 'gnus-treading 'custom-loads '("gnus-sum"))
(put 'strokes 'custom-loads '("strokes"))
(put 'mouse 'custom-loads '("mouse" "menu-bar" "avoid" "goto-addr" "mouse-sel" "msb" "strokes"))
(put 'nnmail-various 'custom-loads '("nnmail"))
(put 'extensions 'custom-loads '("generic" "iswitchb" "time-stamp" "wid-edit" "cust-print" "eldoc" "page-ext"))
(put 'appt 'custom-loads '("appt"))
(put 'snmp 'custom-loads '("snmp-mode"))
(put 'speedbar-faces 'custom-loads '("speedbar" "vhdl-mode"))
(put 'rmail 'custom-loads '("rmail"))
(put 'message-various 'custom-loads '("message"))
(put 'term 'custom-loads '("terminal" "term"))
(put 'gnus-summary-exit 'custom-loads '("gnus-sum" "gnus"))
(put 'news 'custom-loads '("gnus" "message" "supercite"))
(put 'ada 'custom-loads '("ada-mode" "ada-stmt"))
(put 'gnus 'custom-loads '("gnus-art" "gnus" "gnus-demon" "gnus-dup" "gnus-eform" "gnus-undo" "gnus-uu" "gnus-win" "nnmail"))
(put 'cperl-affected-by-hairy 'custom-loads '("cperl-mode"))
(put 'reftex-making-and-inserting-labels 'custom-loads '("reftex"))
(put 'calendar-hooks 'custom-loads '("calendar"))
(put 'mailalias 'custom-loads '("mailalias"))
(put 'frames 'custom-loads '("frame" "scroll-bar" "desktop" "ediff-wind" "imenu" "rsz-mini" "two-column"))
(put 'gnus-server 'custom-loads '("gnus"))
(put 'paren-showing 'custom-loads '("paren"))
(put 'dos-fns 'custom-loads '("dos-vars"))
(put 'display-time 'custom-loads '("time"))
(put 'reftex 'custom-loads '("reftex"))
(put 'makemode 'custom-loads '("make-mode"))
(put 'hexl 'custom-loads '("hexl"))
(put 'gnus-summary-visual 'custom-loads '("gnus-sum" "gnus"))
(put 'gnus-group-listing 'custom-loads '("gnus-group"))
(put 'rmail-reply 'custom-loads '("rmail"))
(put 'gnus-score 'custom-loads '("gnus-nocem" "gnus"))
(put 'gnus-group-select 'custom-loads '("gnus-sum" "gnus"))
(put 'archive-lzh 'custom-loads '("arc-mode"))
(put 'vhdl-sequential-process 'custom-loads '("vhdl-mode"))
(put 'simula 'custom-loads '("simula"))
(put 'vhdl-comment 'custom-loads '("vhdl-mode"))
(put 'message-buffers 'custom-loads '("message"))
(put 'generic 'custom-loads '("generic-x" "generic"))
(put 'docs 'custom-loads '("info" "makeinfo" "texinfo"))
(put 'indent 'custom-loads '("indent"))
(put 'enriched 'custom-loads '("enriched"))
(put 'gnus-threading 'custom-loads '("gnus-sum"))
(put 'hide-ifdef 'custom-loads '("hideif"))
(put 'vip 'custom-loads '("vip"))
(put 'spell 'custom-loads '("spell"))
(put 'rmail-headers 'custom-loads '("rmail"))
(put 'gnus-score-decay 'custom-loads '("gnus-score"))
(put 'cperl-autoinsert-details 'custom-loads '("cperl-mode"))
(put 'help 'custom-loads '("help" "cus-edit" "info-look" "info" "man"))
(put 'forms 'custom-loads '("forms"))
(put 'widget-documentation 'custom-loads '("wid-edit"))
(put 'gnus-score-various 'custom-loads '("gnus-score" "gnus"))
(put 'cperl-faces 'custom-loads '("cperl-mode"))
(put 'goto-address 'custom-loads '("goto-addr"))
(put 'gnus-nocem 'custom-loads '("gnus-nocem"))
(put 'gnus-group-visual 'custom-loads '("gnus-group" "gnus"))
(put 'paren-matching 'custom-loads '("simple" "paren"))
(put 'reftex-viewing-cross-references-and-citations 'custom-loads '("reftex"))
(put 'font-lock 'custom-loads '("font-lock"))
(put 'backquote 'custom-loads '("backquote"))
(put 'auto-save 'custom-loads '("files" "startup"))
(put 'tpu 'custom-loads '("tpu-edt" "tpu-extras"))
(put 'gnus-cite 'custom-loads '("gnus-cite"))
(put 'viper-hooks 'custom-loads '("viper-init"))
(put 'gnus-demon 'custom-loads '("gnus-demon"))
(put 'reftex-optimizations-for-large-documents 'custom-loads '("reftex"))
(put 'viper-misc 'custom-loads '("viper-cmd" "viper-init" "viper"))
(put 'tmm 'custom-loads '("tmm"))
(put 'gnus-message 'custom-loads '("message" "gnus"))
(put 'mh-buffer 'custom-loads '("mh-utils"))
(put 'feedmail-queue 'custom-loads '("feedmail"))
(put 'cmuscheme 'custom-loads '("cmuscheme" "xscheme"))
(put 'file-cache 'custom-loads '("filecache"))
(put 'uce 'custom-loads '("uce"))
(put 'boolean 'custom-loads '("bookmark"))
(put 'backup 'custom-loads '("files"))
(put 'matching 'custom-loads '("simple" "isearch" "replace" "bookmark" "completion" "ffap" "imenu"))
(put 'custom-faces 'custom-loads '("cus-edit"))
(put 'smtpmail 'custom-loads '("smtpmail"))
(put 'lisp-indent 'custom-loads '("cl-indent"))
(put 'midnight 'custom-loads '("midnight"))
(put 'tex 'custom-loads '("bibtex" "reftex" "tex-mode"))
(put 'cperl-indentation-details 'custom-loads '("cperl-mode"))
(put 'mail-extr 'custom-loads '("mail-extr"))
(put 'double 'custom-loads '("double"))
(put 'imenu 'custom-loads '("imenu"))
(put 'scribe 'custom-loads '("scribe"))
(put 'server 'custom-loads '("server"))
(put 'tcl 'custom-loads '("tcl-mode"))
(put 'vhdl-print 'custom-loads '("vhdl-mode"))
(put 'gnus-summary-tree 'custom-loads '("gnus-salt"))
(put 'tar 'custom-loads '("tar-mode"))
(put 'archive 'custom-loads '("arc-mode"))
(put 'ps-print 'custom-loads '("ps-print"))
(put 'view 'custom-loads '("view"))
(put 'gnus-score-default 'custom-loads '("gnus-score" "gnus-sum"))
(put 'nnmail-duplicate 'custom-loads '("nnmail"))
(put 'handwrite 'custom-loads '("handwrite"))
(put 'tags 'custom-loads '("speedbar"))
(put 'custom-browse 'custom-loads '("cus-edit"))
(put 'generic-x 'custom-loads '("generic-x"))
(put 'partial-completion 'custom-loads '("complete"))
(put 'maint 'custom-loads '("gulp" "lisp-mnt" "emacsbug"))
(put 'pages 'custom-loads '("page-ext"))
(put 'message-interface 'custom-loads '("message"))
(put 'diary 'custom-loads '("calendar" "diary-lib"))
(put 'custom-magic-faces 'custom-loads '("cus-edit"))
(put 'emacsbug 'custom-loads '("emacsbug"))
(put 'mh-compose 'custom-loads '("mh-comp"))
(put 'tex-view 'custom-loads '("tex-mode"))
(put 'nnmail-files 'custom-loads '("nnmail"))
(put 'gnus-edit-form 'custom-loads '("gnus-eform"))
(put 'modula2 'custom-loads '("modula2"))
(put 'ps-print-color 'custom-loads '("ps-print"))
(put 'emacs 'custom-loads '("cus-edit"))
(put 'comint 'custom-loads '("comint"))
(put 'isearch 'custom-loads '("isearch"))
(put 'reftex-fontification-configurations 'custom-loads '("reftex"))
(put 'auto-insert 'custom-loads '("autoinsert"))
(put 'abbrev 'custom-loads '("files" "cus-edit" "dabbrev" "expand" "hippie-exp"))
(put 'ediff-merge 'custom-loads '("ediff-init" "ediff-merg"))
(put 'vhdl 'custom-loads '("vhdl-mode"))
(put 'gnus-summary-mail 'custom-loads '("gnus-sum"))
(put 'apropos 'custom-loads '("apropos"))
(put 'gomoku 'custom-loads '("gomoku"))
(put 'tools 'custom-loads '("add-log" "compare-w" "diff" "ediff" "emerge" "gud" "rcompile" "speedbar" "tempo" "vc" "which-func" "copyright" "compile" "etags" "make-mode"))
(put 'gnus-topic 'custom-loads '("gnus-topic"))
(put 'sgml 'custom-loads '("sgml-mode"))
(put 'keyboard 'custom-loads '("chistory" "type-break"))
(put 'viper-mouse 'custom-loads '("viper-mous"))
(put 'ps-print-horizontal 'custom-loads '("ps-print"))
(put 'decipher 'custom-loads '("decipher"))
(put 'ps-print-face 'custom-loads '("ps-print"))
(put 'rmail-summary 'custom-loads '("rmail" "rmailsum"))
(put 'metamail 'custom-loads '("metamail"))
(put 'winner 'custom-loads '("winner"))
(put 'wp 'custom-loads '("cus-edit" "enriched" "lpr" "ps-print" "view" "bib-mode" "nroff-mode" "refbib" "refer" "scribe"))
(put 'reftex-citation-support 'custom-loads '("reftex"))
(put 'gnus-summary-choose 'custom-loads '("gnus-sum"))
(put 'widget-browse 'custom-loads '("wid-browse"))
(put 'feedmail-misc 'custom-loads '("feedmail"))
(put 'diff 'custom-loads '("diff"))
(put 'unix 'custom-loads '("gud" "rlogin" "shell" "term" "sh-script"))
(put 'external 'custom-loads '("bib-mode" "cus-edit" "locate" "server"))
(put 'vc 'custom-loads '("files" "vc-hooks" "vc"))
(put 'vhdl-highlight-faces 'custom-loads '("vhdl-mode"))
(put 'which-func 'custom-loads '("which-func"))
(put 'pc-select 'custom-loads '("pc-select"))
(put 'i18n 'custom-loads '("cus-edit" "double" "ccl" "iso-acc" "iso-ascii" "ogonek"))
(put 'sh 'custom-loads '("sh-script"))
(put 'message-headers 'custom-loads '("message"))
(put 'basic-faces 'custom-loads '("cus-edit"))
(put 'net-utils 'custom-loads '("net-utils"))
(put 'facemenu 'custom-loads '("facemenu"))
(put 'pp 'custom-loads '("pp"))
(put 'two-column 'custom-loads '("two-column"))
(put 'message-forwarding 'custom-loads '("message"))
(put 'ph 'custom-loads '("ph"))
(put 'message-faces 'custom-loads '("message"))
(put 'environment 'custom-loads '("cus-edit" "dired" "dos-vars"))
(put 'perl 'custom-loads '("perl-mode"))
(put 'vhdl-port 'custom-loads '("vhdl-mode"))
(put 'custom-menu 'custom-loads '("cus-edit"))
(put 'comm 'custom-loads '("net-utils" "ph"))
(put 'type-break 'custom-loads '("type-break"))
(put 'mh 'custom-loads '("mh-comp" "mh-e" "mh-utils"))
(put 'convenience 'custom-loads '("abbrev" "autoinsert" "autorevert" "complete" "completion" "dabbrev" "ffap" "filecache" "follow" "hippie-exp" "imenu" "iswitchb" "repeat" "speedbar" "pc-select"))
(put 'lm 'custom-loads '("landmark"))
(put 'm4 'custom-loads '("m4-mode"))
(put 'gnus-article-mime 'custom-loads '("gnus-art" "gnus-sum"))
(put 'emulations 'custom-loads '("crisp" "tpu-edt" "vip" "viper"))
(put 'compression 'custom-loads '("jka-compr"))
(put 'games 'custom-loads '("bruce" "decipher" "dunnet" "gametree" "gomoku" "handwrite" "landmark" "mpuz" "solitaire" "spook" "yow"))
(put 'Help 'custom-loads '("apropos"))
(put 'nnmail-retrieve 'custom-loads '("nnmail"))
(put 'gnus-duplicate 'custom-loads '("gnus-dup"))
(put 'find-function 'custom-loads '("find-func"))
(put 'menu 'custom-loads '("tmm" "easymenu"))
(put 'vhdl-highlight 'custom-loads '("vhdl-mode"))
(put 'widgets 'custom-loads '("wid-browse" "wid-edit"))
(put 'abbrev-mode 'custom-loads '("abbrev" "cus-edit" "mailabbrev"))
(put 'earcon 'custom-loads '("earcon"))
(put 'feedmail-headers 'custom-loads '("feedmail"))
(put 'hypermedia 'custom-loads '("browse-url" "goto-addr" "wid-edit" "metamail"))
(put 'ff 'custom-loads '("find-file"))
(put 'prolog 'custom-loads '("prolog"))
(put 'follow 'custom-loads '("follow"))
(put 'info 'custom-loads '("info"))
(put 'battery 'custom-loads '("battery"))
(put 'texinfo 'custom-loads '("texinfo"))
(put 'dired-mark 'custom-loads '("dired"))
(put 'lazy-lock 'custom-loads '("lazy-lock"))
(put 'makeinfo 'custom-loads '("makeinfo"))
(put 'supercite-cite 'custom-loads '("supercite"))
(put 'speedbar-vc 'custom-loads '("speedbar"))
(put 'save-place 'custom-loads '("saveplace"))
(put 'msb 'custom-loads '("msb"))
(put 'eldoc 'custom-loads '("eldoc"))
(put 'change-log 'custom-loads '("add-log"))
(put 'gnus-group-levels 'custom-loads '("gnus-group" "gnus-start" "gnus"))
(put 'cperl 'custom-loads '("cperl-mode"))
(put 'files 'custom-loads '("files" "ange-ftp" "autoinsert" "autorevert" "cus-edit" "filecache" "shadow"))
(put 'rmail-files 'custom-loads '("rmail"))
(put 'gnus-summary-format 'custom-loads '("gnus-sum" "gnus"))
(put 'terminals 'custom-loads '("terminal"))
(put 'avoid 'custom-loads '("avoid"))
(put 'compare-w 'custom-loads '("compare-w"))
(put 'gnus-files 'custom-loads '("gnus" "nnmail"))
(put 'gnus-windows 'custom-loads '("gnus-win"))
(put 'reftex-label-support 'custom-loads '("reftex"))
(put 'gnus-article-buttons 'custom-loads '("gnus-art"))
(put 'old-c 'custom-loads '("c-mode" "cc-vars"))
(put 'gnus-summary 'custom-loads '("gnus-sum" "gnus"))
(put 'compilation 'custom-loads '("compile"))
(put 'ediff-highlighting 'custom-loads '("ediff-init"))
(put 'xscheme 'custom-loads '("xscheme"))
(put 'checkdoc 'custom-loads '("checkdoc"))
(put 'gnus-article-hiding 'custom-loads '("gnus-art" "gnus-sum"))
(put 'vhdl-mode 'custom-loads '("vhdl-mode"))
(put 'lpr 'custom-loads '("lpr"))
(put 'ispell 'custom-loads '("ispell"))
(put 'auto-revert 'custom-loads '("autorevert"))
(put 'advice 'custom-loads '("advice"))
(put 'picture 'custom-loads '("picture"))
(put 'gnus-group 'custom-loads '("gnus-topic" "gnus"))
(put 'reftex-referencing-labels 'custom-loads '("reftex"))
(put 'gnus-article-various 'custom-loads '("gnus-art" "gnus-sum"))
(put 'ediff-diff 'custom-loads '("ediff-diff"))
(put 'supercite 'custom-loads '("supercite"))
(put 'gnus-summary-marks 'custom-loads '("gnus-sum" "gnus"))
(put 'bibtex-autokey 'custom-loads '("bibtex"))
(put 'octave 'custom-loads '("octave-inf" "octave-mod"))
(put 'editing-basics 'custom-loads '("simple" "files" "delsel" "pc-select"))
(put 'hscroll 'custom-loads '("hscroll"))
(put 'nnmail-expire 'custom-loads '("gnus" "nnmail"))
(put 'gnus-article-saving 'custom-loads '("gnus-art"))
(put 'icomplete 'custom-loads '("icomplete"))
(put 'LaTeX 'custom-loads '("reftex"))
(put 'man 'custom-loads '("man"))
(put 'solitaire 'custom-loads '("solitaire"))
(put 'hippie-expand 'custom-loads '("hippie-exp"))
(put 'refer 'custom-loads '("refer"))
(put 'message-mail 'custom-loads '("message"))
(put 'modeline 'custom-loads '("time"))
(put 'archive-zoo 'custom-loads '("arc-mode"))
(put 'gnus-group-level 'custom-loads '("gnus"))
(put 'bibtex 'custom-loads '("bibtex"))
(put 'faces 'custom-loads '("faces" "facemenu" "cus-edit" "font-lock" "hilit-chg" "paren" "ps-print" "speedbar" "wid-edit" "gnus" "message" "fontset" "make-mode"))
(put 'fill-comments 'custom-loads '("simple"))
(put 'gnus-summary-various 'custom-loads '("gnus-sum"))
(put 'applications 'custom-loads '("calendar" "cus-edit" "uniquify" "spell"))
(put 'terminal 'custom-loads '("terminal"))
(put 'shadow 'custom-loads '("shadowfile" "shadow"))
(put 'internal 'custom-loads '("startup" "cus-edit"))
(put 'lisp 'custom-loads '("lisp" "cmuscheme" "ielm" "backquote" "xscheme" "advice" "bytecomp" "checkdoc" "cl-indent" "cust-print" "edebug" "elp" "find-func" "pp" "shadow" "trace" "scheme"))
(put 'local 'custom-loads '("calendar"))
(put 'rlogin 'custom-loads '("rlogin"))
(put 'debugger 'custom-loads '("debug"))
(put 'archive-zip 'custom-loads '("arc-mode"))
(put 'gnus-start-server 'custom-loads '("gnus-start"))
(put 'debug 'custom-loads '("debug"))
(put 'vhdl-electric 'custom-loads '("vhdl-mode"))
(put 'gnus-extract-archive 'custom-loads '("gnus-uu"))
(put 'message 'custom-loads '("startup" "message"))
(put 'message-sending 'custom-loads '("message"))
(put 'archive-arc 'custom-loads '("arc-mode"))
(put 'rmail-output 'custom-loads '("rmailout"))
(put 'editing 'custom-loads '("simple" "indent" "paragraphs" "auto-show" "cus-edit" "outline" "hscroll" "vcursor" "view" "picture"))
(put 'crisp 'custom-loads '("crisp"))
(put 'nroff 'custom-loads '("nroff-mode"))
(put 'executable 'custom-loads '("executable"))
(put 'gnus-score-adapt 'custom-loads '("gnus-score" "gnus"))
(put 'ada-stmt 'custom-loads '("ada-stmt"))
(put 'copyright 'custom-loads '("copyright"))
(put 'bytecomp 'custom-loads '("bytecomp"))
(put 'message-insertion 'custom-loads '("message"))
(put 'gnus-extract-post 'custom-loads '("gnus-uu"))
(put 'pascal 'custom-loads '("pascal"))
(put 'rmail-retrieve 'custom-loads '("rmail"))
(put 'data 'custom-loads '("arc-mode" "forms" "hexl" "jka-compr" "saveplace" "snmp-mode" "sort" "tar-mode" "time-stamp"))
(put 'mail 'custom-loads '("simple" "startup" "ph" "time" "gnus" "message" "emacsbug" "feedmail" "mail-extr" "mail-hist" "mail-utils" "mailalias" "metamail" "mh-e" "mspools" "rmail" "sendmail" "smtpmail" "supercite" "uce"))
(put 'paren-blinking 'custom-loads '("simple"))
(put 'gnus-summary-sort 'custom-loads '("gnus-sum"))
(put 'fast-lock 'custom-loads '("fast-lock"))
(put 'gnus-group-new 'custom-loads '("gnus-start"))
(put 'viper-highlighting 'custom-loads '("viper-init"))
(put 'customize 'custom-loads '("wid-edit" "cus-edit"))
(put 'dired 'custom-loads '("files" "dired-aux" "dired-x" "dired" "find-dired"))
(put 'fill 'custom-loads '("simple" "fill"))
(put 'ps-print-header 'custom-loads '("ps-print"))
(put 'outlines 'custom-loads '("allout" "outline"))
(put 'paragraphs 'custom-loads '("paragraphs"))
(put 'nnmail-split 'custom-loads '("nnmail"))
(put 'makefile 'custom-loads '("make-mode"))
(put 'supercite-attr 'custom-loads '("supercite"))
(put 'gnus-asynchronous 'custom-loads '("gnus" "gnus-async"))
(put 'vcursor 'custom-loads '("vcursor"))
(put 'iso-ascii 'custom-loads '("iso-ascii"))
(put 'gnus-dribble-file 'custom-loads '("gnus-start"))
(put 'widget-button 'custom-loads '("wid-edit"))
(put 'uniquify 'custom-loads '("uniquify"))
(put 'old-c++ 'custom-loads '("cplus-md"))
(put 'ps-print-font 'custom-loads '("ps-mule" "ps-print"))
(put 'vhdl-misc 'custom-loads '("vhdl-mode"))
(put 'dired-x 'custom-loads '("dired-x"))
(put 'spook 'custom-loads '("spook"))
(put 'tex-file 'custom-loads '("tex-mode"))
(put 'time-stamp 'custom-loads '("time-stamp"))
(put 'gnus-article-highlight 'custom-loads '("gnus-art" "gnus"))
(put 'gud 'custom-loads '("gud"))
(put 'c-macro 'custom-loads '("cmacexp"))
(put 'gnus-cache 'custom-loads '("gnus-cache" "gnus"))
(put 'gnus-extract 'custom-loads '("gnus" "gnus-uu"))
(put 'browse-url 'custom-loads '("browse-url"))
(put 'cust-print 'custom-loads '("cust-print"))
(put 'gnus-article 'custom-loads '("gnus-art" "gnus-cite"))
(put 'fortran-indent 'custom-loads '("fortran"))
(put 'hardware 'custom-loads '("battery"))
(put 'edebug 'custom-loads '("edebug"))
(put 'emerge 'custom-loads '("emerge"))
(put 'scheme 'custom-loads '("scheme"))
(put 'gametree 'custom-loads '("gametree"))
(put 'gnus-group-foreign 'custom-loads '("gnus-group"))
(put 'initialization 'custom-loads '("startup"))
(put 'sh-script 'custom-loads '("sh-script"))
(put 'cperl-speed 'custom-loads '("cperl-mode"))
(put 'calendar 'custom-loads '("midnight" "calendar" "solar"))
(put 'programming 'custom-loads '("cus-edit"))
(put 'meta-font 'custom-loads '("meta-mode"))
(put 'hideshow 'custom-loads '("hideshow"))
(put 'viper-search 'custom-loads '("viper-init"))
(put 'C 'custom-loads '("cpp"))
(put 'mule 'custom-loads '("mule-cmds"))
(put 'vhdl-style 'custom-loads '("vhdl-mode"))
(put 'tempo 'custom-loads '("tempo"))
(put 'c 'custom-loads '("cc-vars" "cmacexp" "hideif"))
(put 'nnmail-prepare 'custom-loads '("nnmail"))
(put 'processes 'custom-loads '("comint" "cus-edit" "rcompile" "rlogin" "shell" "term" "metamail" "compile" "executable" "sql" "flyspell"))
(put 'sendmail 'custom-loads '("sendmail"))
(put 'gnus-article-signature 'custom-loads '("gnus-art"))
(put 'viper-ex 'custom-loads '("viper-ex"))
(put 'gulp 'custom-loads '("gulp"))
(put 'ielm 'custom-loads '("ielm"))
(put 'find-dired 'custom-loads '("find-dired"))
(put 'killing 'custom-loads '("simple"))
(put 'gnus-group-various 'custom-loads '("gnus-group" "gnus"))
;;; These are for handling :version.  We need to have a minimum of
;;; information so `custom-changed-variables' could do its job.  
;;; For both groups and variables we have to set `custom-version'.
;;; For variables we also set the `standard-value' and for groups
;;; `group-documentation' (which is shown in the customize buffer), so
;;; we don't have to load the file containing the group.

;;; `custom-versions-load-alist' is an alist that has as car a version
;;; number and as elts the files that have variables that contain that
;;; version. These files should be loaded before showing the
;;; customization buffer that `customize-changed-options' generates.


;;; This macro is used so we don't modify the information about
;;; variables and groups if it's already set. (We don't know when
;;; cus-load.el is going to be loaded and at that time some of the
;;; files might be loaded and some others might not).
(defmacro custom-put-if-not (symbol propname value)
  `(unless (get ,symbol ,propname)
     (put ,symbol ,propname ,value)))

(custom-put-if-not 'SQL 'custom-version "20.4")
(custom-put-if-not 'SQL 'group-documentation "Running a SQL interpreter from within Emacs buffers")
(custom-put-if-not 'highlight-changes 'custom-version "20.4")
(custom-put-if-not 'highlight-changes 'group-documentation "Highlight Changes mode.")
(custom-put-if-not 'query-replace-from-history-variable 'custom-version "20.3")
(custom-put-if-not 'query-replace-from-history-variable 'standard-value t)
(custom-put-if-not 'custom-variable-default-form 'custom-version "20.3")
(custom-put-if-not 'custom-variable-default-form 'standard-value t)
(custom-put-if-not 'vc-ignore-vc-files 'custom-version "20.3")
(custom-put-if-not 'vc-ignore-vc-files 'standard-value t)
(custom-put-if-not 'find-function-after-hook 'custom-version "20.3")
(custom-put-if-not 'find-function-after-hook 'standard-value t)
(custom-put-if-not 'add-log-keep-changes-together 'custom-version "20.3")
(custom-put-if-not 'add-log-keep-changes-together 'standard-value t)
(custom-put-if-not 'browse-url-lynx-input-field 'custom-version "20.3")
(custom-put-if-not 'browse-url-lynx-input-field 'standard-value t)
(custom-put-if-not 'help-highlight-face 'custom-version "20.3")
(custom-put-if-not 'help-highlight-face 'standard-value t)
(custom-put-if-not 'speedbar 'custom-version "20.3")
(custom-put-if-not 'speedbar 'group-documentation "File and tag browser frame.")
(custom-put-if-not 'octave-auto-indent 'custom-version "20.3")
(custom-put-if-not 'octave-auto-indent 'standard-value t)
(custom-put-if-not 'find-tag-marker-ring-length 'custom-version "20.3")
(custom-put-if-not 'find-tag-marker-ring-length 'standard-value t)
(custom-put-if-not 'flyspell 'custom-version "20.3")
(custom-put-if-not 'flyspell 'group-documentation "Spellchecking on the fly.")
(custom-put-if-not 'compilation-scroll-output 'custom-version "20.3")
(custom-put-if-not 'compilation-scroll-output 'standard-value t)
(custom-put-if-not 'vc-dired-recurse 'custom-version "20.3")
(custom-put-if-not 'vc-dired-recurse 'standard-value t)
(custom-put-if-not 'display-time-mode 'custom-version "20.3")
(custom-put-if-not 'display-time-mode 'standard-value t)
(custom-put-if-not 'snmp 'custom-version "20.4")
(custom-put-if-not 'snmp 'group-documentation "Mode for editing SNMP MIB files.")
(custom-put-if-not 'help-highlight-p 'custom-version "20.3")
(custom-put-if-not 'help-highlight-p 'standard-value t)
(custom-put-if-not 'browse-url-mosaic-program 'custom-version "20.3")
(custom-put-if-not 'browse-url-mosaic-program 'standard-value t)
(custom-put-if-not 'find-function-regexp 'custom-version "20.3")
(custom-put-if-not 'find-function-regexp 'standard-value t)
(custom-put-if-not 'vcursor-string 'custom-version "20.3")
(custom-put-if-not 'vcursor-string 'standard-value t)
(custom-put-if-not 'custom-face-default-form 'custom-version "20.3")
(custom-put-if-not 'custom-face-default-form 'standard-value t)
(custom-put-if-not 'hexl-follow-ascii 'custom-version "20.3")
(custom-put-if-not 'hexl-follow-ascii 'standard-value t)
(custom-put-if-not 'mouse-avoidance-mode 'custom-version "20.3")
(custom-put-if-not 'mouse-avoidance-mode 'standard-value t)
(custom-put-if-not 'browse-url-filename-alist 'custom-version "20.3")
(custom-put-if-not 'browse-url-filename-alist 'standard-value t)
(custom-put-if-not 'midnight 'custom-version "20.3")
(custom-put-if-not 'midnight 'group-documentation "Run something every day at midnight.")
(custom-put-if-not 'generic-x 'custom-version "20.3")
(custom-put-if-not 'generic-x 'group-documentation "Extra modes for generic mode.")
(custom-put-if-not 'debugger-mode-hook 'custom-version "20.3")
(custom-put-if-not 'debugger-mode-hook 'standard-value t)
(custom-put-if-not 'vcursor-interpret-input 'custom-version "20.3")
(custom-put-if-not 'vcursor-interpret-input 'standard-value t)
(custom-put-if-not 'vhdl 'custom-version "20.4")
(custom-put-if-not 'vhdl 'group-documentation "Customizations for VHDL Mode.")
(custom-put-if-not 'find-function-recenter-line 'custom-version "20.3")
(custom-put-if-not 'find-function-recenter-line 'standard-value t)
(custom-put-if-not 'mail-citation-prefix-regexp 'custom-version "20.3")
(custom-put-if-not 'mail-citation-prefix-regexp 'standard-value t)
(custom-put-if-not 'diary-mail-days 'custom-version "20.3")
(custom-put-if-not 'diary-mail-days 'standard-value t)
(custom-put-if-not 'diary-mail-addr 'custom-version "20.3")
(custom-put-if-not 'diary-mail-addr 'standard-value t)
(custom-put-if-not 'compilation-error-screen-columns 'custom-version "20.4")
(custom-put-if-not 'compilation-error-screen-columns 'standard-value t)
(custom-put-if-not 'debugger-record-buffer 'custom-version "20.3")
(custom-put-if-not 'debugger-record-buffer 'standard-value t)
(custom-put-if-not 'query-replace-to-history-variable 'custom-version "20.3")
(custom-put-if-not 'query-replace-to-history-variable 'standard-value t)
(custom-put-if-not 'which-func 'custom-version "20.3")
(custom-put-if-not 'which-func 'group-documentation "Mode to display the current function name in the modeline.")
(custom-put-if-not 'mouse-buffer-menu-mode-mult 'custom-version "20.3")
(custom-put-if-not 'mouse-buffer-menu-mode-mult 'standard-value t)
(custom-put-if-not 'net-utils 'custom-version "20.3")
(custom-put-if-not 'net-utils 'group-documentation "Network utility functions.")
(custom-put-if-not 'uce-mail-reader 'custom-version "20.3")
(custom-put-if-not 'uce-mail-reader 'standard-value t)
(custom-put-if-not 'dos-codepage-setup-hook 'custom-version "20.3.3")
(custom-put-if-not 'dos-codepage-setup-hook 'standard-value t)
(custom-put-if-not 'temp-buffer-resize-mode 'custom-version "20.4")
(custom-put-if-not 'temp-buffer-resize-mode 'standard-value t)
(custom-put-if-not 'cperl 'custom-version "20.3")
(custom-put-if-not 'cperl 'group-documentation "Major mode for editing Perl code.")
(custom-put-if-not 'focus-follows-mouse 'custom-version "20.3")
(custom-put-if-not 'focus-follows-mouse 'standard-value t)
(custom-put-if-not 'checkdoc 'custom-version "20.3")
(custom-put-if-not 'checkdoc 'group-documentation "Support for doc string checking in Emacs Lisp.")
(custom-put-if-not 'mail-abbrevs-mode 'custom-version "20.3")
(custom-put-if-not 'mail-abbrevs-mode 'standard-value t)
(custom-put-if-not 'sh-imenu-generic-expression 'custom-version "20.3")
(custom-put-if-not 'sh-imenu-generic-expression 'standard-value t)
(custom-put-if-not 'temp-buffer-max-height 'custom-version "20.4")
(custom-put-if-not 'temp-buffer-max-height 'standard-value t)
(custom-put-if-not 'show-paren-ring-bell-on-mismatch 'custom-version "20.3")
(custom-put-if-not 'show-paren-ring-bell-on-mismatch 'standard-value t)
(custom-put-if-not 'rmail-default-body-file 'custom-version "20.3")
(custom-put-if-not 'rmail-default-body-file 'standard-value t)
(custom-put-if-not 'rmail-movemail-flags 'custom-version "20.3")
(custom-put-if-not 'rmail-movemail-flags 'standard-value t)
(custom-put-if-not 'dired-at-point-require-prefix 'custom-version "20.3")
(custom-put-if-not 'dired-at-point-require-prefix 'standard-value t)
(custom-put-if-not 'dabbrev-ignored-buffer-names 'custom-version "20.3")
(custom-put-if-not 'dabbrev-ignored-buffer-names 'standard-value t)
(custom-put-if-not 'diary-unknown-time 'custom-version "20.3")
(custom-put-if-not 'diary-unknown-time 'standard-value t)
(custom-put-if-not 'browse-url-lynx-emacs-args 'custom-version "20.3")
(custom-put-if-not 'browse-url-lynx-emacs-args 'standard-value t)
(custom-put-if-not 'vc-default-init-version 'custom-version "20.3")
(custom-put-if-not 'vc-default-init-version 'standard-value t)
(custom-put-if-not 'gametree 'custom-version "20.3")
(custom-put-if-not 'gametree 'group-documentation "Manage game analysis trees in Emacs.")
(custom-put-if-not 'hscroll-global-mode 'custom-version "20.3")
(custom-put-if-not 'hscroll-global-mode 'standard-value t)
(custom-put-if-not 'find-variable-regexp 'custom-version "20.3")
(custom-put-if-not 'find-variable-regexp 'standard-value t)
(custom-put-if-not 'easy-menu-precalculate-equivalent-keybindings 'custom-version "20.3")
(custom-put-if-not 'easy-menu-precalculate-equivalent-keybindings 'standard-value t)
(custom-put-if-not 'desktop-enable 'custom-version "20.3")
(custom-put-if-not 'desktop-enable 'standard-value t)
(custom-put-if-not 'vc-dired-terse-display 'custom-version "20.3")
(custom-put-if-not 'vc-dired-terse-display 'standard-value t)

(defvar custom-versions-load-alist '(("20.3.3" "dos-vars") ("20.4" "help" "compile") ("20.3" "desktop" "easymenu" "hscroll" "dabbrev" "ffap" "rmail" "paren" "sh-script" "mailabbrev" "frame" "uce" "mouse" "diary-lib" "sendmail" "debug" "avoid" "hexl" "vcursor" "time" "vc" "compile" "etags" "octave-mod" "help" "browse-url" "add-log" "find-func" "vc-hooks" "cus-edit" "replace"))
 "For internal use by custom.")

(provide 'cus-load)

;;; cus-load.el ends here
