(setq load-history
      (nconc load-history
             '(("ediff-hook" ediff-menu ediff-merge-menu epatch-menu ediff-misc-menu ediff-window-setup-function ediff-xemacs-init-menus menu-bar-ediff-misc-menu menu-bar-epatch-menu menu-bar-ediff-merge-menu menu-bar-ediff-menu (provide . ediff-hook))
               ("vc-hooks" vc-default-back-end vc-handle-cvs vc-rcsdiff-knows-brief vc-path vc-master-templates vc-make-backup-files vc-follow-symlinks vc-display-status vc-consult-headers vc-keep-workfiles vc-mistrust-permissions vc-ignore-vc-files vc-mistrust-permissions vc-error-occurred vc-file-prop-obarray vc-buffer-backend vc-file-setprop vc-file-getprop vc-file-clearprops vc-match-substring vc-lock-file vc-parse-buffer vc-insert-file vc-parse-locks vc-simple-command vc-parse-cvs-status vc-fetch-master-properties vc-consult-rcs-headers vc-backend-subdirectory-name vc-name vc-backend vc-checkout-model vc-cvs-status vc-master-locks vc-master-locking-user vc-lock-from-permissions vc-user-login-name vc-file-owner vc-rcs-lock-from-diff vc-locking-user vc-latest-version vc-your-latest-version vc-master-workfile-version vc-fetch-properties vc-workfile-version vc-registered vc-sccs-project-dir vc-search-sccs-project-dir vc-find-cvs-master vc-buffer-backend vc-toggle-read-only vc-after-save vc-mode-line vc-status vc-follow-link vc-find-file-hook vc-file-not-found-hook vc-kill-buffer-hook (provide . vc-hooks))
               ("float-sup" pi e degrees-to-radians radians-to-degrees degrees-to-radians radians-to-degrees (provide . lisp-float-type))
               ("buff-menu" Buffer-menu-buffer-column Buffer-menu-mode-map Buffer-menu-mode Buffer-menu-revert Buffer-menu-revert-function Buffer-menu-buffer buffer-menu buffer-menu-other-window Buffer-menu-mark Buffer-menu-unmark Buffer-menu-backup-unmark Buffer-menu-delete Buffer-menu-delete-backwards Buffer-menu-save Buffer-menu-not-modified Buffer-menu-execute Buffer-menu-select Buffer-menu-visit-tags-table Buffer-menu-1-window Buffer-menu-mouse-select Buffer-menu-this-window Buffer-menu-other-window Buffer-menu-switch-other-window Buffer-menu-2-window Buffer-menu-toggle-read-only Buffer-menu-bury list-buffers list-buffers-noselect)
               ("abbrev" only-global-abbrevs abbrev-mode abbrev-mode edit-abbrevs-map kill-all-abbrevs insert-abbrevs list-abbrevs prepare-abbrev-list-buffer edit-abbrevs-mode edit-abbrevs edit-abbrevs-redefine define-abbrevs read-abbrev-file quietly-read-abbrev-file write-abbrev-file add-mode-abbrev add-global-abbrev add-abbrev inverse-add-mode-abbrev inverse-add-global-abbrev inverse-add-abbrev abbrev-prefix-mark expand-region-abbrevs)
               ("replace" case-replace query-replace-history query-replace-interactive query-replace-from-history-variable query-replace-to-history-variable query-replace-read-args query-replace query-replace-regexp map-query-replace-regexp replace-string replace-regexp regexp-history delete-non-matching-lines keep-lines delete-matching-lines flush-lines count-matches how-many occur-mode-map occur-buffer occur-nlines occur-command-arguments occur-mode occur-revert-function occur-mode-mouse-goto occur-mode-find-occurrence occur-mode-goto-occurrence occur-next occur-prev list-matching-lines-default-context-lines list-matching-lines list-matching-lines-face occur query-replace-help query-replace-map perform-replace query-replace-highlight replace-overlay replace-dehighlight replace-highlight)
               ("textmodes/fill" fill-individual-varying-indent sentence-end-double-space colon-double-space sentence-end-without-period fill-paragraph-function enable-kinsoku set-fill-prefix adaptive-fill-mode adaptive-fill-regexp adaptive-fill-first-line-regexp adaptive-fill-function current-fill-column canonically-space-region fill-context-prefix fill-nobreak-predicate fill-find-break-point fill-region-as-paragraph fill-paragraph fill-region default-justification current-justification set-justification set-justification-none set-justification-left set-justification-right set-justification-full set-justification-center justify-current-line unjustify-current-line unjustify-region fill-nonuniform-paragraphs fill-individual-paragraphs fill-individual-paragraphs-prefix fill-individual-paragraphs-citation)
               ("textmodes/text-mode" text-mode-hook text-mode-variant text-mode-syntax-table text-mode-abbrev-table text-mode-map text-mode paragraph-indent-text-mode indented-text-mode text-mode-hook-identify toggle-text-mode-auto-fill center-paragraph center-region center-line)
               ("emacs-lisp/lisp-mode" lisp-mode-syntax-table emacs-lisp-mode-syntax-table lisp-mode-abbrev-table lisp-imenu-generic-expression lisp-mode-variables shared-lisp-mode-map emacs-lisp-mode-map emacs-lisp-byte-compile emacs-lisp-byte-compile-and-load emacs-lisp-mode lisp-mode-map lisp-mode lisp-eval-defun lisp-interaction-mode-map lisp-interaction-mode eval-print-last-sexp eval-last-sexp eval-defun lisp-comment-indent lisp-mode-auto-fill lisp-indent-offset lisp-indent-function lisp-indent-line calculate-lisp-indent-last-sexp calculate-lisp-indent lisp-indent-function lisp-body-indent lisp-indent-specform lisp-indent-defform indent-sexp lisp-indent-region lisp-fill-paragraph indent-code-rigidly (provide . lisp-mode))
               ("textmodes/paragraphs" use-hard-newlines use-hard-newlines paragraph-start paragraph-separate sentence-end page-delimiter paragraph-ignore-fill-prefix forward-paragraph backward-paragraph mark-paragraph kill-paragraph backward-kill-paragraph transpose-paragraphs start-of-paragraph-text end-of-paragraph-text forward-sentence backward-sentence kill-sentence backward-kill-sentence mark-end-of-sentence transpose-sentences)
               ("register" register-alist get-register set-register point-to-register window-configuration-to-register frame-configuration-to-register register-to-point jump-to-register register-swap-out number-to-register increment-register view-register insert-register copy-to-register append-to-register prepend-to-register copy-rectangle-to-register)
               ("textmodes/page" forward-page backward-page mark-page narrow-to-page count-lines-page what-page (provide . page))
               ("emacs-lisp/lisp" defun-prompt-regexp parens-require-spaces forward-sexp backward-sexp mark-sexp forward-list backward-list down-list backward-up-list up-list kill-sexp backward-kill-sexp beginning-of-defun beginning-of-defun-raw buffer-end end-of-defun mark-defun narrow-to-defun insert-parentheses move-past-close-and-reindent lisp-complete-symbol)
               ("startup" command-line-processed inhibit-startup-message inhibit-startup-echo-area-message inhibit-default-init command-switch-alist command-line-args-left command-line-functions command-line-default-directory command-line-x-option-alist before-init-hook after-init-hook emacs-startup-hook term-setup-hook keyboard-type window-setup-hook initial-major-mode init-file-user site-run-file iso-8859-n-locale-regexp mail-host-address user-mail-address auto-save-list-file-prefix locale-translation-file-name init-file-debug init-file-had-error normal-top-level-add-subdirs-inode-list normal-top-level-add-subdirs-to-load-path normal-top-level-add-to-load-path normal-top-level precompute-menubar-bindings command-line initial-scratch-message command-line-1 command-line-normalize-file-name)
               ("paths.el" Info-default-directory-list news-path news-inews-program gnus-default-nntp-server gnus-nntp-service gnus-local-organization gnus-startup-file rmail-file-name rmail-spool-directory sendmail-program remote-shell-program term-file-prefix abbrev-file-name)
               ("menu-bar" buffers-menu-max-size menu-bar-help-menu menu-bar-search-menu menu-bar-edit-menu menu-bar-tools-menu menu-bar-files-menu menu-bar-file-menu vc-menu-map menu-bar-print-menu nonincremental-search-forward nonincremental-search-backward nonincremental-re-search-forward nonincremental-re-search-backward nonincremental-repeat-search-forward nonincremental-repeat-search-backward nonincremental-repeat-re-search-forward nonincremental-repeat-re-search-backward yank-menu menu-bar-kill-ring-save clipboard-yank clipboard-kill-ring-save clipboard-kill-region menu-bar-enable-clipboard menu-bar-custom-menu menu-bar-options-menu menu-bar-make-toggle menu-bar-describe-menu menu-bar-manuals-menu kill-this-buffer kill-this-buffer-enabled-p delete-frame-enabled-p yank-menu-length menu-bar-update-yank-menu menu-bar-select-yank list-buffers-directory menu-bar-update-buffers-maxbuf menu-bar-select-buffer menu-bar-select-frame menu-bar-update-buffers-1 menu-bar-buffers-menu-list-buffers-entry menu-bar-update-buffers menu-bar-mode menu-bar-mode (provide . menu-bar))
               ("select" x-selection x-get-selection x-get-clipboard x-set-selection x-valid-simple-selection-p x-get-cut-buffer x-set-cut-buffer xselect-convert-to-string xselect-convert-to-length xselect-convert-to-targets xselect-convert-to-delete xselect-convert-to-filename xselect-convert-to-charpos xselect-convert-to-lineno xselect-convert-to-colno xselect-convert-to-os xselect-convert-to-host xselect-convert-to-user xselect-convert-to-class xselect-convert-to-name xselect-convert-to-integer xselect-convert-to-atom xselect-convert-to-identity (provide . select))
               ("scroll-bar" (require . mouse) scroll-bar-event-ratio scroll-bar-scale scroll-bar-mode scroll-bar-mode-explicit set-scroll-bar-mode-1 set-scroll-bar-mode scroll-bar-mode scroll-bar-mode toggle-scroll-bar toggle-horizontal-scroll-bar scroll-bar-set-window-start scroll-bar-drag-position scroll-bar-maybe-set-window-start scroll-bar-drag-1 scroll-bar-drag scroll-bar-scroll-down scroll-bar-scroll-up (provide . scroll-bar))
               ("mouse" mouse-yank-at-point mouse-major-mode-menu mouse-major-mode-menu-1 mouse-minibuffer-check mouse-delete-window mouse-select-window mouse-tear-off-window mouse-delete-other-windows mouse-split-window-vertically mouse-split-window-horizontally mouse-drag-mode-line mouse-drag-vertical-line mouse-set-point mouse-last-region-beg mouse-last-region-end mouse-last-region-tick mouse-region-match mouse-set-region mouse-set-region-1 mouse-scroll-delay mouse-scroll-min-lines mouse-scroll-subr mouse-drag-overlay mouse-selection-click-count mouse-selection-click-count-buffer mouse-drag-region mouse-skip-word mouse-start-end mouse-set-mark-fast mouse-undouble-last-event mouse-region-delete-keys mouse-show-mark mouse-set-mark mouse-kill mouse-yank-at-click mouse-kill-ring-save mouse-save-then-kill-posn mouse-save-then-kill-delete-region mouse-save-then-kill mouse-secondary-overlay mouse-secondary-click-count mouse-secondary-start mouse-start-secondary mouse-set-secondary mouse-drag-secondary mouse-yank-secondary mouse-kill-secondary mouse-secondary-save-then-kill mouse-buffer-menu-maxlen mouse-buffer-menu-mode-mult mouse-buffer-menu-mode-groups mouse-buffer-menu mouse-buffer-menu-alist mouse-buffer-menu-split mouse-choose-completion font-menu-add-default x-fixed-font-alist mouse-set-font (provide . mouse))
               ("facemenu" (provide . facemenu) facemenu-keybindings facemenu-new-faces-at-end facemenu-unlisted-faces facemenu-face-menu facemenu-face-menu facemenu-foreground-menu facemenu-foreground-menu facemenu-background-menu facemenu-background-menu facemenu-special-menu facemenu-special-menu facemenu-justification-menu facemenu-justification-menu facemenu-indentation-menu facemenu-indentation-menu facemenu-menu facemenu-menu facemenu-keymap facemenu-keymap facemenu-add-face-function facemenu-end-add-face facemenu-remove-face-function facemenu-color-alist facemenu-update facemenu-set-face facemenu-set-foreground facemenu-set-background facemenu-set-face-from-menu facemenu-set-invisible facemenu-set-intangible facemenu-set-read-only facemenu-remove-face-props facemenu-remove-all facemenu-remove-special list-text-properties-at facemenu-read-color list-colors-display facemenu-color-equal facemenu-add-face facemenu-active-faces facemenu-get-face facemenu-add-new-face facemenu-complete-face-list facemenu-iterate)
               ("faces" internal-facep facep internal-check-face face-name face-id face-font face-foreground face-background face-stipple face-background-pixmap face-underline-p face-inverse-video-p face-font-explicit face-bold-p face-italic-p face-doc-string face-documentation set-face-font set-face-font-auto set-face-font-explicit set-face-foreground face-default-stipple face-color-gray-p set-face-background set-face-stipple set-face-background-pixmap set-face-underline-p set-face-inverse-video-p set-face-bold-p set-face-italic-p set-face-doc-string set-face-documentation modify-face-read-string modify-face global-face-data face-list internal-find-face internal-get-face internal-set-face-1 read-face-name internal-face-interactive internal-face-interactive-stipple make-face make-empty-face make-face-x-resource-internal copy-face face-equal face-differs-from-default-p face-nontrivial-p invert-face internal-try-face-font x-font-regexp x-font-regexp-head x-font-regexp-weight x-font-regexp-slant x-font-regexp-weight-subnum x-font-regexp-slant-subnum x-font-regexp-swidth-subnum x-font-regexp-adstyle-subnum x-resolve-font-name x-frob-font-weight x-frob-font-slant x-make-font-bold x-make-font-demibold x-make-font-unbold x-make-font-italic x-make-font-oblique x-make-font-unitalic x-make-font-bold-italic make-face-bold make-face-bold-internal make-face-italic make-face-italic-internal make-face-bold-italic make-face-bold-italic-internal make-face-unbold make-face-unitalic list-faces-sample-text list-faces-display describe-face face-attr-match-p face-attr-match-1 face-spec-match-p face-attr-construct face-spec-choose face-spec-set face-spec-set-1 face-spec-set-match-display x-create-frame-with-faces face-set-after-frame-default frame-background-mode frame-set-background-mode frame-update-faces frame-update-face-colors face-fill-in face-color-supported-p face-try-color-list (provide . faces))
               ("frame" frame-creation-function initial-frame-alist minibuffer-frame-alist pop-up-frame-alist special-display-frame-alist special-display-popup-frame handle-delete-frame frame-initial-frame frame-initial-frame-alist frame-initial-geometry-arguments frame-initialize frame-notice-user-settings make-initial-minibuffer-frame frame-delete-all get-other-frame next-multiframe-window previous-multiframe-window make-frame-on-display make-frame-command before-make-frame-hook after-make-frame-functions new-frame make-frame filtered-frame-list minibuffer-frame-list frame-remove-geometry-params focus-follows-mouse other-frame make-frame-names-alist frame-name-history select-frame-by-name current-frame-configuration set-frame-configuration frame-parameter frame-height frame-width set-default-font set-frame-font set-background-color set-foreground-color set-cursor-color set-mouse-color set-border-color auto-raise-mode auto-lower-mode set-frame-name screen-height screen-width set-screen-width set-screen-height (provide . frame))
               ("window" one-window-p walk-windows minibuffer-window-active-p save-selected-window count-windows balance-windows split-window-keep-point split-window-vertically view-return-to-alist split-window-save-restore-data split-window-horizontally enlarge-window-horizontally shrink-window-horizontally window-buffer-height shrink-window-if-larger-than-buffer kill-buffer-and-window quit-window)
               ("isearch" search-exit-option search-slow-window-lines search-slow-speed search-upper-case search-nonincremental-instead search-whitespace-regexp search-highlight search-invisible isearch-hide-immediately isearch-mode-hook isearch-mode-end-hook search-ring regexp-search-ring search-ring-max regexp-search-ring-max search-ring-yank-pointer regexp-search-ring-yank-pointer search-ring-update isearch-mode-map minibuffer-local-isearch-map isearch-forward isearch-regexp isearch-word isearch-cmds isearch-string isearch-message isearch-success isearch-invalid-regexp isearch-within-brackets isearch-other-end isearch-wrapped isearch-barrier isearch-just-started isearch-case-fold-search isearch-adjusted isearch-slow-terminal-mode isearch-small-window isearch-opoint isearch-window-configuration isearch-yank-flag isearch-op-fun isearch-recursive-edit isearch-nonincremental isearch-new-forward isearch-opened-overlays isearch-input-method-function isearch-input-method-local-p isearch-mode isearch-forward isearch-forward-regexp isearch-backward isearch-backward-regexp isearch-mode-help isearch-mode isearch-update isearch-done isearch-update-ring isearch-switch-frame-handler isearch-exit isearch-edit-string isearch-nonincremental-exit-minibuffer isearch-forward-exit-minibuffer isearch-reverse-exit-minibuffer isearch-cancel isearch-abort isearch-repeat isearch-repeat-forward isearch-repeat-backward isearch-toggle-regexp isearch-toggle-case-fold isearch-delete-char isearch-yank-string isearch-yank-kill isearch-yank-x-selection isearch-yank-word isearch-yank-line isearch-search-and-update isearch-*-char isearch-|-char isearch-other-control-char isearch-other-meta-char isearch-quote-char isearch-return-char isearch-printing-char isearch-whitespace-chars isearch-process-search-char isearch-process-search-string isearch-ring-adjust1 isearch-ring-adjust isearch-ring-advance isearch-ring-retreat isearch-ring-advance-edit isearch-ring-retreat-edit isearch-complete1 isearch-complete isearch-complete-edit isearch-top-state isearch-pop-state isearch-push-state isearch-message isearch-message-prefix isearch-message-suffix isearch-search isearch-open-overlay-temporary isearch-open-necessary-overlays isearch-clean-overlays isearch-close-unecessary-overlays isearch-range-invisible isearch-overlay isearch-highlight isearch-dehighlight isearch-no-upper-case-p isearch-char-to-string isearch-text-char-description isearch-unread isearch-last-command-char)
               ("indent" standard-indent indent-line-function indent-according-to-mode indent-for-tab-command insert-tab indent-rigidly indent-line-to current-left-margin move-to-left-margin indent-to-left-margin delete-to-left-margin set-left-margin set-right-margin alter-text-property increase-left-margin decrease-left-margin increase-right-margin decrease-right-margin beginning-of-line-text indent-region-function indent-region indent-relative-maybe indent-relative tab-stop-list edit-tab-stops-map edit-tab-stops-buffer edit-tab-stops edit-tab-stops-note-changes tab-to-tab-stop move-to-tab-stop)
               ("language/misc-lang" setup-ipa-environment)
               ("language/vietnamese" viet-viscii-decode-table viet-viscii-encode-table viet-vscii-decode-table viet-vscii-encode-table ccl-decode-viscii ccl-encode-viscii ccl-encode-viscii-font ccl-decode-vscii ccl-encode-vscii ccl-encode-vscii-font viet-viscii-nonascii-translation-table)
               ("language/tibetan" tibetan-consonant-transcription-alist tibetan-vowel-transcription-alist tibetan-precomposed-transcription-alist tibetan-subjoined-transcription-alist tibetan-base-to-subjoined-alist tibetan-precomposition-rule-alist tibetan-regexp tibetan-precomposed-regexp tibetan-precomposition-rule-regexp tibetan-decomposed tibetan-decomposed-temp)
               ("language/thai")
               ("language/lao")
               ("language/korean")
               ("language/japanese")
               ("language/hebrew" setup-hebrew-environment)
               ("language/greek" setup-greek-environment)
               ("language/romanian" setup-romanian-environment (provide . romanian))
               ("language/slovak" setup-slovak-environment (provide . slovak))
               ("language/czech" setup-czech-environment (provide . czech))
               ("language/european" setup-latin1-environment setup-latin2-environment setup-latin3-environment setup-latin4-environment setup-latin5-environment setup-german-environment setup-slovenian-environment (provide . slovenian))
               ("language/ethiopic" ccl-encode-ethio-font)
               ("language/english" setup-english-environment)
               ("language/devanagari" devanagari-1-column-char)
               ("language/indian" indian-itrans-consonant-alist indian-itrans-vowel-sign-alist indian-itrans-other-letters-alist indian-itrans-regexp itrans-indian-regexp indian-itrans-alist indian-decode-itrans-region indian-encode-itrans-region)
               ("language/cyrillic" cyrillic-koi8-r-decode-table cyrillic-koi8-r-encode-table ccl-decode-koi8 ccl-encode-koi8 ccl-encode-koi8-font cyrillic-koi8-r-nonascii-translation-table cyrillic-alternativnyj-decode-table cyrillic-alternativnyj-encode-table ccl-decode-alternativnyj ccl-encode-alternativnyj ccl-encode-alternativnyj-font cyrillic-alternativnyj-nonascii-translation-table)
               ("language/chinese" post-read-decode-hz pre-write-encode-hz ccl-encode-big5-font)
               ("international/latin-5" (require . case-table))
               ("international/latin-4" (require . case-table))
               ("international/latin-3" (require . case-table))
               ("international/latin-2" (require . case-table))
               ("international/latin-1" (require . case-table))
               ("loaddefs.el" add-log-full-name add-log-mailing-address add-log-lisp-like-modes add-log-c-like-modes add-log-tex-like-modes ad-redefinition-action ad-default-compilation-action ange-ftp-re-read-dir appt-issue-message appt-message-warning-time appt-audible appt-visible appt-display-mode-line appt-msg-window appt-display-duration appt-display-diary auto-show-mode \` bookmark-map bookmark-locate list-bookmarks edit-bookmarks menu-bar-bookmark-map menu-bar-bookmark-map browse-url-browser-function browse-url-new-window-p browse-url-netscape-display browse-url-save-file browse-url-generic-program browse-url-grail calendar-week-start-day calendar-offset view-diary-entries-initially number-of-diary-entries mark-diary-entries-in-calendar view-calendar-holidays-initially mark-holidays-in-calendar all-hebrew-calendar-holidays all-christian-calendar-holidays all-islamic-calendar-holidays calendar-load-hook initial-calendar-window-hook today-visible-calendar-hook today-invisible-calendar-hook diary-file diary-nonmarking-symbol hebrew-diary-entry-symbol islamic-diary-entry-symbol diary-include-string sexp-diary-entry-symbol abbreviated-calendar-year european-calendar-style american-date-diary-pattern european-date-diary-pattern european-calendar-display-form american-calendar-display-form print-diary-entries-hook list-diary-entries-hook diary-hook diary-display-hook nongregorian-diary-listing-hook mark-diary-entries-hook nongregorian-diary-marking-hook diary-list-include-blanks holidays-in-diary-buffer general-holidays oriental-holidays local-holidays other-holidays hebrew-holidays-1 hebrew-holidays-2 hebrew-holidays-3 hebrew-holidays-4 hebrew-holidays christian-holidays islamic-holidays solar-holidays calendar-setup c-mode-syntax-table c++-mode-syntax-table objc-mode-syntax-table java-mode-syntax-table idl-mode-syntax-table pike-mode-syntax-table c-emacs-features custom-print-functions compilation-mode-hook compilation-window-height compilation-process-setup-function compilation-buffer-name-function compilation-finish-function compilation-finish-functions compilation-ask-about-save compilation-search-path crisp-mode customize-variable customize-variable-other-window custom-file pending-delete-mode delete-selection-mode diff-switches diff-command dired-listing-switches dired-chown-program dired-ls-F-marks-symlinks dired-trivial-filenames dired-keep-marker-rename dired-keep-marker-copy dired-keep-marker-hardlink dired-keep-marker-symlink dired-dwim-target dired-copy-preserve-time edebug-all-defs edebug-all-forms edebug-defun ediff3 ediff ebuffers ebuffers3 edirs edir-revisions edirs3 edirs-merge edir-merge-revisions edir-merge-revisions-with-ancestor edirs-merge-with-ancestor ediff-merge ediff-merge-with-ancestor epatch epatch-buffer erevision eregistry edmacro-eight-bits eldoc-mode menu-bar-emerge-menu tags-file-name tags-table-list tags-add-tables find-tag-hook find-tag-default-function facemenu-face-menu facemenu-face-menu facemenu-foreground-menu facemenu-foreground-menu facemenu-background-menu facemenu-background-menu facemenu-special-menu facemenu-special-menu facemenu-justification-menu facemenu-justification-menu facemenu-indentation-menu facemenu-indentation-menu facemenu-menu facemenu-menu find-ls-option find-grep-options font-lock-mode-hook fortran-tab-mode-default gnus-batch-kill three-step-help hide-ifdef-initially hide-ifdef-read-only hide-ifdef-lines hs-hide-comments-when-hiding-all hs-show-hidden-short-form hs-special-modes-alist hippie-expand-try-functions-list hippie-expand-verbose hippie-expand-dabbrev-skip-space hippie-expand-dabbrev-as-symbol hippie-expand-no-restriction hippie-expand-max-buffers hippie-expand-ignore-buffers hippie-expand-only-buffers imenu-sort-function imenu-generic-expression imenu-create-index-function imenu-prev-index-position-function imenu-extract-index-name-function imenu-default-goto-function inferior-lisp-filter-regexp inferior-lisp-program inferior-lisp-load-command inferior-lisp-prompt inferior-lisp-mode-hook run-lisp ispell-personal-dictionary ispell-local-dictionary-alist ispell-dictionary-alist ispell-menu-map ispell-menu-xemacs ispell-menu-map-needed ispell-skip-region-alist ispell-tex-skip-alists auto-compression-mode default-korean-keyboard landmark-repeat landmark ledit-save-files ledit-go-to-lisp-string ledit-go-to-liszt-string printer-name lpr-switches lpr-command ls-lisp-support-shell-wildcards mail-hist-keep-history mail-use-rfc822 mail-complete-style manual-entry message-from-style message-signature-separator message-user-organization-file message-send-mail-function message-citation-line-function message-yank-prefix message-cite-function message-indent-citation-function message-signature message-signature-file mh-mime-content-types msb-mode string-to-list string-to-vector truncate-string nested-alist-p reference-point-alist ifconfig disabled-command-hook run-octave pc-selection-mode edit-picture bdf-directory-list ps-multibyte-buffer ps-paper-type close-rectangle rmail-dont-reply-to-names rmail-default-dont-reply-to-names rmail-ignored-headers rmail-displayed-headers rmail-retry-ignored-headers rmail-highlighted-headers rmail-highlight-face rmail-delete-after-output rmail-primary-inbox-list rmail-mail-new-frame rmail-secondary-file-directory rmail-secondary-file-regexp rmail-mode-hook rmail-get-new-mail-hook rmail-show-message-hook rmail-delete-message-hook rmail-file-coding-system rmail-enable-mime rmail-show-mime-function rmail-mime-feature rmail-decode-mime-charset rmail-mime-charset-pattern rmail-output-file-alist rmail-fields-not-to-output rmail-summary-scroll-between-messages rmail-summary-line-count-flag rmail-summary-line-decoder resize-minibuffer-mode resize-minibuffer-window-max-height resize-minibuffer-window-exactly resize-minibuffer-frame resize-minibuffer-frame-max-height resize-minibuffer-frame-exactly mail-from-style mail-self-blind mail-interactive mail-yank-ignored-headers send-mail-function mail-header-separator mail-archive-file-name mail-default-reply-to mail-alias-file mail-personal-alias-file mail-signature sendmail-coding-system default-sendmail-coding-system shell-script-mode shell-prompt-pattern skeleton-filter calendar-time-display-form calendar-latitude calendar-longitude calendar-location-name speedbar strokes-mode global-set-stroke describe-stroke load-user-strokes tex-shell-file-name tex-directory tex-first-line-header-regexp tex-main-file tex-offer-save tex-run-command latex-run-command slitex-run-command tex-start-options-string latex-block-names tex-bibtex-command tex-dvi-print-command tex-alt-dvi-print-command tex-dvi-view-command tex-show-queue-command tex-default-mode tex-open-quote tex-close-quote TeX-mode plain-TeX-mode LaTeX-mode display-time-day-and-date disable-timeout trace-buffer type-break-mode type-break-interval type-break-good-rest-interval type-break-keystroke-threshold vc-checkin-hook vc-before-checkin-hook vc-annotate-mode-hook view-mode which-func-mode-global which-function-mode winner-mode)
               ("international/characters")
               ("case-table" set-case-syntax-offset set-case-syntax-set-multibyte describe-buffer-case-table copy-case-table set-case-syntax-1 set-case-syntax-delims set-case-syntax-pair set-case-syntax (provide . case-table))
               ("international/mule-cmds" mule-keymap mule-menu-keymap describe-language-environment-map setup-language-environment-map set-coding-system-map coding-system-change-eol-conversion coding-system-change-text-conversion toggle-enable-multibyte-characters view-hello-file universal-coding-system-argument set-default-coding-systems update-iso-coding-systems prefer-coding-system find-coding-systems-region-subset-p find-coding-systems-region find-coding-systems-string find-coding-systems-for-charsets find-multibyte-characters last-coding-system-specified select-safe-coding-system select-message-coding-system language-info-alist get-language-info set-language-info set-language-info-alist read-language-name leim-list-file-name leim-list-header leim-list-entry-regexp update-leim-list-functions update-leim-list-file current-input-method current-input-method-title default-input-method input-method-history inactivate-current-input-method-function describe-current-input-method-function input-method-alist register-input-method read-input-method-name activate-input-method inactivate-input-method set-input-method toggle-input-method describe-input-method describe-current-input-method read-multilingual-string input-method-verbose-flag input-method-highlight-flag input-method-activate-hook input-method-inactivate-hook input-method-after-insert-chunk-hook input-method-exit-on-first-char input-method-use-echo-area input-method-exit-on-invalid-key set-language-environment-hook exit-language-environment-hook setup-specified-language-environment current-language-environment reset-language-environment set-language-environment standard-display-european-internal set-language-environment-coding-systems princ-list describe-specified-language-support describe-language-environment get-charset-property put-charset-property char-code-property-table get-char-code-property put-char-code-property iso-2022-control-alist encoded-string-description encode-coding-char)
               ("files" delete-auto-save-files directory-abbrev-alist make-backup-files backup-inhibited backup-by-copying backup-by-copying-when-linked backup-by-copying-when-mismatch backup-enable-predicate buffer-offer-save find-file-existing-other-name find-file-visit-truename revert-without-query buffer-file-number buffer-file-numbers-unique file-name-invalid-regexp file-precious-flag version-control dired-kept-versions delete-old-versions kept-old-versions kept-new-versions require-final-newline auto-save-default auto-save-visited-file-name save-abbrevs find-file-run-dired find-file-not-found-hooks find-file-hooks write-file-hooks local-write-file-hooks write-contents-hooks enable-local-variables local-enable-local-variables enable-local-eval view-read-only temporary-file-directory null-device ange-ftp-completion-hook-function convert-standard-filename pwd cd-path parse-colon-path cd-absolute cd load-file load-library file-local-copy file-truename file-chase-links switch-to-buffer-other-window switch-to-buffer-other-frame find-file find-file-other-window find-file-other-frame find-file-read-only find-file-read-only-other-window find-file-read-only-other-frame find-alternate-file-other-window find-alternate-file create-file-buffer generate-new-buffer automount-dir-prefix abbreviated-home-dir abbreviate-file-name find-file-not-true-dirname-list find-buffer-visiting find-file-wildcards find-file-noselect find-file-noselect-1 insert-file-contents-literally insert-file-literally find-file-literally find-file-literally after-find-file-from-revert-buffer after-find-file normal-mode auto-mode-alist interpreter-mode-alist inhibit-first-line-modes-regexps inhibit-first-line-modes-suffixes user-init-file set-auto-mode hack-local-variables-prop-line hack-local-variables-hook hack-local-variables ignored-local-variables hack-one-local-variable-quotep hack-one-local-variable change-major-mode-with-file-name set-visited-file-name write-file backup-buffer file-name-sans-versions file-ownership-preserved-p file-name-sans-extension file-name-extension make-backup-file-name backup-file-name-p backup-extract-version-start backup-extract-version find-backup-file-name file-nlinks file-relative-name save-buffer delete-auto-save-file-if-necessary auto-save-hook after-save-hook save-buffer-coding-system basic-save-buffer basic-save-buffer-1 basic-save-buffer-2 save-some-buffers not-modified toggle-read-only insert-file append-to-file file-newest-backup rename-uniquely make-directory revert-buffer-function revert-buffer-insert-file-contents-function before-revert-hook after-revert-hook revert-buffer-internal-hook revert-buffer recover-file recover-session recover-session-finish kill-some-buffers auto-save-mode rename-auto-save-file make-auto-save-file-name auto-save-file-name-p wildcard-to-regexp list-directory-brief-switches list-directory-verbose-switches file-expand-wildcards list-directory insert-directory-program insert-directory kill-emacs-query-functions save-buffers-kill-emacs file-name-non-special)
               ("help" help-map help-mode-map help-xref-stack help-xref-stack-item help-mode help-mode-setup help-mode-finish help-quit help-with-tutorial describe-key-briefly help-return-method print-help-return-message describe-key describe-mode describe-distribution describe-copying describe-project describe-no-warranty describe-prefix-bindings view-emacs-news view-emacs-FAQ view-lossage help help-for-help-doc help-for-help function-called-at-point symbol-file-load-history-loaded symbol-file describe-function describe-function-1 variable-at-point describe-variable describe-bindings where-is locate-library help-highlight-p help-highlight-face help-back-label help-xref-symbol-regexp help-xref-info-regexp help-setup-xref help-make-xrefs help-xref-button help-xref-interned help-xref-mode help-follow-mouse help-xref-go-back help-go-back help-follow help-next-ref help-previous-ref temp-buffer-resize-mode temp-buffer-max-height temp-buffer-resize-mode resize-temp-buffer-window)
               ("simple" newline set-hard-newline-properties open-line split-line quoted-insert delete-indentation join-line fixup-whitespace delete-horizontal-space just-one-space delete-blank-lines back-to-indentation newline-and-indent reindent-then-newline-and-indent kill-forward-chars kill-backward-chars backward-delete-char-untabify-method backward-delete-char-untabify zap-to-char beginning-of-buffer end-of-buffer mark-whole-buffer count-lines-region what-line count-lines what-cursor-position fundamental-mode read-expression-map read-expression-history eval-expression edit-and-eval-command repeat-complex-command minibuffer-history minibuffer-history-sexp-flag minibuffer-history-search-history minibuffer-text-before-history minibuffer-history-initialize minibuffer-history-case-insensitive-variables previous-matching-history-element next-matching-history-element next-history-element previous-history-element next-complete-history-element previous-complete-history-element goto-line advertised-undo undo pending-undo-list undo-in-progress undo-more undo-copy-list undo-copy-list-1 undo-start undo-adjusted-markers undo-make-selective-list undo-elt-in-region undo-elt-crosses-region undo-delta shell-command-history shell-command-switch shell-command-default-error-buffer shell-command shell-command-sentinel shell-command-on-region shell-command-to-string universal-argument-map universal-argument-num-events universal-argument universal-argument-more negative-argument digit-argument universal-argument-minus universal-argument-other-key forward-to-indentation backward-to-indentation kill-whole-line kill-line forward-visible-line end-of-visible-line interprogram-cut-function interprogram-paste-function kill-ring kill-ring-max kill-ring-yank-pointer kill-new kill-append current-kill kill-read-only-ok kill-region copy-region-as-kill kill-ring-save append-next-kill yank-pop yank rotate-yank-pointer insert-buffer append-to-buffer prepend-to-buffer copy-to-buffer mark deactivate-mark set-mark mark-ring mark-ring-max global-mark-ring global-mark-ring-max set-mark-command push-mark pop-mark exchange-dot-and-mark exchange-point-and-mark transient-mark-mode pop-global-mark next-line-add-newlines next-line previous-line track-eol goal-column temporary-goal-column line-move-ignore-invisible line-move set-goal-column hscroll-step hscroll-point-visible hscroll-window-column scroll-other-window-down beginning-of-buffer-other-window end-of-buffer-other-window transpose-chars transpose-words transpose-sexps transpose-lines transpose-subr-start1 transpose-subr-start2 transpose-subr-end1 transpose-subr-end2 transpose-subr transpose-subr-1 comment-column comment-start comment-start-skip comment-end comment-indent-hook comment-indent-function block-comment-start block-comment-end indent-for-comment set-comment-column kill-comment comment-padding comment-region backward-word mark-word kill-word backward-kill-word current-word fill-prefix auto-fill-inhibit-regexp comment-line-break-function do-auto-fill normal-auto-fill-function auto-fill-mode auto-fill-function turn-on-auto-fill set-fill-column comment-multi-line indent-new-comment-line set-selective-display overwrite-mode-textual overwrite-mode-binary overwrite-mode binary-overwrite-mode line-number-mode line-number-mode column-number-mode column-number-mode blink-matching-paren blink-matching-paren-on-screen blink-matching-paren-distance blink-matching-delay blink-matching-paren-dont-ignore-comments blink-matching-open keyboard-quit buffer-quit-function keyboard-escape-quit mail-user-agent define-mail-user-agent assoc-ignore-case assoc-ignore-representation rfc822-goto-eoh sendmail-user-agent-compose compose-mail compose-mail-other-window compose-mail-other-frame set-variable-value-history set-variable completion-list-mode-map completion-reference-buffer completion-no-auto-exit completion-base-size delete-completion-window previous-completion next-completion choose-completion choose-completion-delete-max-match choose-completion-string completion-list-mode completion-setup-hook completion-setup-function switch-to-completions event-apply-alt-modifier event-apply-super-modifier event-apply-hyper-modifier event-apply-shift-modifier event-apply-control-modifier event-apply-meta-modifier event-apply-modifier)
               ("bindings" mode-line-mule-info mode-line-buffer-identification mode-line-frame-identification mode-line-process mode-line-modified minor-mode-alist complete-symbol mode-specific-command-prefix mode-specific-map point-to-register-compatibility-binding jump-to-register-compatibility-binding copy-to-register-compatibility-binding insert-register-compatibility-binding)
               ("format" format-alist format-encode-run-method format-decode-run-method format-annotate-function format-decode format-decode-buffer format-decode-region format-encode-buffer format-encode-region format-write-file format-find-file format-insert-file format-read format-replace-strings format-delq-cons format-make-relatively-unique format-common-tail format-reorder format-deannotate-region format-subtract-regions format-property-increment-region format-insert-annotations format-annotate-value format-annotate-region format-annotate-location format-annotate-single-property-change format-annotate-atomic-property-change (provide . format))
               ("international/mule-conf.el")
               ("international/mule" mule-version mule-version-date load-with-code-conversion charset-quoted-standard-p charsetp charset-info charset-id charset-bytes charset-dimension charset-chars charset-width charset-direction charset-iso-final-char charset-iso-graphic-plane charset-reverse-charset charset-short-name charset-long-name charset-description charset-plist set-charset-plist make-char charset-list generic-char-p coding-spec-type-idx coding-spec-mnemonic-idx coding-spec-doc-string-idx coding-spec-plist-idx coding-spec-flags-idx coding-system-spec coding-system-type coding-system-mnemonic coding-system-doc-string coding-system-plist coding-system-flags coding-system-get coding-system-put coding-system-category coding-system-base coding-system-parent coding-system-eol-type coding-system-lessp add-to-coding-system-list coding-system-list make-subsidiary-coding-system make-coding-system define-coding-system-alias set-buffer-file-coding-system default-terminal-coding-system set-terminal-coding-system default-keyboard-coding-system set-keyboard-coding-system set-buffer-process-coding-system set-clipboard-coding-system set-selection-coding-system last-next-selection-coding-system set-next-selection-coding-system set-coding-priority auto-coding-alist set-auto-coding-for-load auto-coding-alist-lookup set-auto-coding set-auto-coding-1 after-insert-file-set-buffer-file-coding-system find-new-buffer-file-coding-system modify-coding-system-alist make-translation-table make-translation-table-from-vector define-translation-table (provide . mule))
               ("cus-start")
               ("custom" (require . widget) custom-define-hook custom-initialize-default custom-initialize-set custom-initialize-reset custom-initialize-changed custom-declare-variable defcustom defface custom-declare-group defgroup custom-add-to-group custom-handle-all-keywords custom-handle-keyword custom-add-option custom-add-link custom-add-version custom-add-load custom-local-buffer custom-set-variables custom-set-default read-quoted-char-radix (provide . custom))
               ("widget" define-widget-keywords define-widget (provide . widget))
               ("map-ynp" map-y-or-n-p)
               ("version.el" emacs-version emacs-major-version emacs-minor-version emacs-build-time emacs-build-system emacs-version version)
               ("subr" custom-declare-variable-list custom-declare-variable-early lambda when unless caar cadr cdar cddr last assoc-default undefined suppress-keymap key-substitution-in-progress substitute-key-definition define-key-after kbd keyboard-translate global-map esc-map ctl-x-map ctl-x-4-map ctl-x-4-prefix ctl-x-5-map ctl-x-5-prefix listify-key-sequence-1 listify-key-sequence eventp event-modifiers event-basic-type mouse-movement-p event-start event-end event-click-count posn-window posn-point posn-x-y posn-col-row posn-timestamp dot dot-marker dot-min dot-max window-dot set-window-dot read-input send-string send-region show-buffer buffer-flush-undo eval-current-buffer compiled-function-p define-function sref baud-rate focus-frame unfocus-frame string= string< move-marker not rplaca rplacd beep indent-to-column backward-delete-char search-forward-regexp search-backward-regexp int-to-string store-match-data string-to-int make-local-hook add-hook remove-hook add-to-list eval-after-load eval-next-after-load read-quoted-char-radix read-quoted-char read-passwd force-mode-line-update momentary-string-display font-lock-defaults suspend-hook suspend-resume-hook buffer-file-type get-buffer-window-list ignore error user-original-login-name start-process-shell-command with-current-buffer with-temp-file with-temp-message with-temp-buffer with-output-to-string combine-after-change-calls save-match-data-internal save-match-data match-string match-string-no-properties split-string subst-char-in-string shell-quote-argument make-syntax-table add-to-invisibility-spec remove-from-invisibility-spec global-set-key local-set-key global-unset-key local-unset-key frame-configuration-p functionp)
               ("byte-run" defsubst make-obsolete make-obsolete-variable dont-compile eval-when-compile eval-and-compile)
)))
